==> haskell-httpd-shed-0.4.1.1-107-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-httpd-shed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 httpd-shed
version:              0.4.1.1
visibility:           public
id:                   httpd-shed-0.4.1.1-HAvHUg21fYmJDRkKxsEpX6
key:                  httpd-shed-0.4.1.1-HAvHUg21fYmJDRkKxsEpX6
license:              BSD-3-Clause
copyright:            (c) 2009 Andy Gill
maintainer:           Ganesh Sittampalam
author:               Andy Gill, Brandon Moore, Henning Thielemann, John Van Enk.
synopsis:             A simple web-server with an interact style API
description:
    This web server promotes a Request to IO Response function
    into a local web server. The user can decide how to interpret
    the requests, and the library is intended for implementing Ajax APIs.

category:             Network, Web
abi:                  5a8568ad11bb8b03483aac562aeab44b
exposed:              True
exposed-modules:      Network.Shed.Httpd
import-dirs:          /usr/lib/ghc-8.10.1/site-local/httpd-shed-0.4.1.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/httpd-shed-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/httpd-shed-0.4.1.1
hs-libraries:         HShttpd-shed-0.4.1.1-HAvHUg21fYmJDRkKxsEpX6
depends:
    base-4.14.0.0 network-3.1.1.1-I205ehn629wJW4axo8gUI9
    network-bsd-2.8.1.0-DAKWSrd75IKIurmKoD5mg6
    network-uri-2.6.3.0-E1HvqUeKxRMK7Pkj5hKUx7

haddock-interfaces:   /usr/share/doc/haskell-httpd-shed/html/httpd-shed.haddock
haddock-html:         /usr/share/doc/haskell-httpd-shed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-httpd-shed-0.4.1.1-116-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-httpd-shed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 httpd-shed
version:              0.4.1.1
visibility:           public
id:                   httpd-shed-0.4.1.1-8qzSK4RCZey8UD5nnp1d22
key:                  httpd-shed-0.4.1.1-8qzSK4RCZey8UD5nnp1d22
license:              BSD-3-Clause
copyright:            (c) 2009 Andy Gill
maintainer:           Ganesh Sittampalam
author:               Andy Gill, Brandon Moore, Henning Thielemann, John Van Enk.
synopsis:             A simple web-server with an interact style API
description:
    This web server promotes a Request to IO Response function
    into a local web server. The user can decide how to interpret
    the requests, and the library is intended for implementing Ajax APIs.

category:             Network, Web
abi:                  4bc48a8a40298a416add9c653aad181d
exposed:              True
exposed-modules:      Network.Shed.Httpd
import-dirs:          /usr/lib/ghc-8.10.1/site-local/httpd-shed-0.4.1.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/httpd-shed-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/httpd-shed-0.4.1.1
hs-libraries:         HShttpd-shed-0.4.1.1-8qzSK4RCZey8UD5nnp1d22
depends:
    base-4.14.0.0 network-3.1.1.1-D3CIp0WkhfC51dOZjHWRWc
    network-bsd-2.8.1.0-C1Vtoau4hBa2faTdPiKqaN
    network-uri-2.6.3.0-FoYLr5uqwqiCQBbBWoaOQC

haddock-interfaces:   /usr/share/doc/haskell-httpd-shed/html/httpd-shed.haddock
haddock-html:         /usr/share/doc/haskell-httpd-shed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
